@@ -1,20 +1,17 @@
-# $Id: Twofish.pm,v 2.12 2001/05/21 17:38:01 ams Exp $
-# Copyright 2001 Abhijit Menon-Sen <ams@toroid.org>
+# $Id: Twofish.pm,v 2.02 2001/05/04 08:10:37 ams Exp $
+# Copyright 2001 Abhijit Menon-Sen <ams@wiw.org>
 
 package Crypt::Twofish;
 
 use strict;
 use Carp;
 use DynaLoader;
-use vars qw( @ISA $VERSION $XS_VERSION );
+use vars qw( @ISA $VERSION );
 
 @ISA = qw( DynaLoader );
-$VERSION = '2.16_001';
-$XS_VERSION = $VERSION;
-$VERSION = eval $VERSION;
+($VERSION) = q$Revision: 2.02 $ =~ /([\d.]+)/;
 
-
-bootstrap Crypt::Twofish $XS_VERSION;
+bootstrap Crypt::Twofish $VERSION;
 
 sub keysize   () { 16 }
 sub blocksize () { 16 }
@@ -100,7 +97,7 @@ and free for all uses, as described at
 This module implements Twofish encryption. It supports the Crypt::CBC
 interface, with the functions described below. It also provides an
 interface that is call-compatible with Crypt::Twofish 1.0, but its use
-in new code is strongly discouraged.
+is strongly discouraged.
 
 =head2 Functions
 
@@ -141,22 +138,16 @@ Crypt::CBC, Crypt::Blowfish, Crypt::TEA
 
 =over 4
 
-=item Nishant Kakani
-
-For writing Crypt::Twofish 1.0 (this version is a complete rewrite).
-
-=item Tony Cook
-
-For making the module work under Activeperl, testing on several
-platforms, and suggesting that I probe for features via %Config.
+=item Nishant Kakani wrote the first version of Crypt::Twofish (this
+version is a complete reimplementation).
 
 =back
 
 =head1 AUTHOR
 
-Abhijit Menon-Sen <ams@toroid.org>
+Abhijit Menon-Sen <ams@wiw.org>
 
-Copyright 2001 Abhijit Menon-Sen.
+Copyright 2001 Abhijit Menon-Sen. All rights reserved.
 
-This module is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+This software is distributed under the terms of the Artistic License
+<URL:http://ams.wiw.org/code/artistic.txt>.
